@@ -22,6 +22,13 @@ class qualified_business_income_deduction(Variable):
         # in 2018 IRS Publication 535, Worksheet 12-A, lines 32-37
         taxinc_less_qbid = tax_unit("taxable_income_less_qbid", period)
         netcg_qdiv = tax_unit("adjusted_net_capital_gain", period)
-        p = parameters(period).gov.irs.deductions.qbi.max
-        taxinc_cap = p.rate * max_(0, taxinc_less_qbid - netcg_qdiv)
-        return min_(uncapped_qbid, taxinc_cap)
+        p = parameters(period).gov.irs.deductions.qbi
+        taxinc_cap = p.max.rate * max_(0, taxinc_less_qbid - netcg_qdiv)
+        pre_floor_qbid = min_(uncapped_qbid, taxinc_cap)
+        if p.deduction_floor.in_effect:
+            qualified_business_income = tax_unit(
+                "qualified_business_income", period
+            )
+            floor = p.deduction_floor.amount.calc(qualified_business_income)
+            return max_(pre_floor_qbid, floor)
+        return pre_floor_qbid
