@@ -14,9 +14,9 @@ class id_grocery_credit_aged(Variable):
     )
 
     def formula(person, period, parameters):
-        p = parameters(period).gov.states.id.tax.income.credits.grocery.amount
+        p = parameters(period).gov.states.id.tax.income.credits.grocery.aged
         # Aged head and spouse are eligible for an additional grocery credit amount
         age = person("age", period)
+        aged = age >= p.age_threshold
         head_or_spouse = person("is_tax_unit_head_or_spouse", period)
-        amount_if_eligible = p.aged.calc(age)
-        return head_or_spouse * amount_if_eligible
+        return aged * head_or_spouse * p.amount
